from .. import __package__ as base_package
import bpy
from bpy.types import Header, Panel
from .funcs import get_scene_workspaces, get_use_global

# Ref TOPBAR_HT_upper_bar https://projects.blender.org/blender/blender/src/commit/2204157a2c9fc926643b0e39968602c750d9b5e6/scripts/startup/bl_ui/space_topbar.py#L14
class TOPBAR_HT_upper_bar(Header):
    bl_space_type = 'TOPBAR'
    
    def draw(self, context):
        region = context.region

        if region.alignment == 'RIGHT':
            self.draw_right(context)
        else:
            self.draw_left(context)

    def draw_left(self, context):
        global workspace_order
        layout = self.layout

        window = context.window
        screen = context.screen

        bpy.types.TOPBAR_MT_editor_menus.draw_collapsible(context, layout)

        layout.separator()
        
        
        # Edited
        use_global = get_use_global()

        if not screen.show_fullscreen:
            main_col = layout.column()
            spacer_row = main_col.row()
            spacer_row.scale_y = .33
            main_row = main_col.row()
            sy = 1.18
            sx = 1.1
            col = main_row.column()
            col.scale_y = sy
            col.operator("sw.switch", text="", emboss=False, icon="RADIOBUT_OFF" if use_global else "RADIOBUT_ON")
            if use_global:
                # Original
                layout.template_ID_tabs(window, "workspace", new="workspace.add", menu="TOPBAR_MT_workspace_menu")
            else:
                r = main_row.row(align=True)
                r.scale_x = 0.87
                r.scale_y = sy
                ws = get_scene_workspaces()
                if not ws and bpy.data.workspaces:
                    c = r.column()
                    c.scale_x = 1.4
                    c.operator("sw.link_all", text="Link all workspaces", icon="LINKED")
                active_not_here = True
                for w in ws:
                    i = ws.index(w)
                    active = bpy.context.window.workspace.name == w
                    if active and i > 0:
                        r.separator()
                    ab = r.box()
                    ab = ab.row(align=True)
                    if active:
                        col = ab.column()
                        col.scale_x = sx
                        col.operator("sw.remove", text="", icon="X", emboss=False).index = i
                    exist = w in [x.name for x in bpy.data.workspaces]
                    ab.operator("sw.workspace", text=w, icon="NONE" if exist else "ERROR", emboss=active, depress=active).workspace = w
                    if active:
                        col = ab.column()
                        col.scale_x = sx
                        col.menu("TOPBAR_MT_workspace_menu", text="", icon="OPTIONS")
                        active_not_here = False
                        r.separator()
                    
                if [x for x in bpy.data.workspaces if x.name not in get_scene_workspaces()]:
                    c = r.column()
                    c.scale_x = sx
                    c.menu("SW_MT_missing_workspaces", text="", icon="THREE_DOTS")
                c = r.column()
                c.scale_x = sx
                c.operator("workspace.add", text="", icon="ADD")
                if len(bpy.data.scenes) > 1:
                    c = r.column()
                    c.scale_x = sx
                    c.menu("SW_MT_copy_from", text="", icon="DUPLICATE")
                    
                if active_not_here:
                    r.separator()
                    r = r.box()
                    r = r.row(align=True)
                    b = r.box()
                    b.scale_x = sx
                    b.operator("sw.link_workspace", text=f"{bpy.context.window.workspace.name} (not linked)", icon="ADD", emboss=True, depress=True).workspace = bpy.context.window.workspace.name
                    col = r.box()
                    col.scale_x = sx
                    col.menu("TOPBAR_MT_workspace_menu", text="", icon="OPTIONS")
        # End Edited 
        else:
            layout.operator("screen.back_to_previous", icon='SCREEN_BACK', text="Back to Previous")

    def draw_right(self, context):
        layout = self.layout

        window = context.window
        screen = context.screen
        scene = window.scene

        # If statusbar is hidden, still show messages at the top
        if not screen.show_statusbar:
            layout.template_reports_banner()
            layout.template_running_jobs()

        # Active workspace view-layer is retrieved through window, not through workspace.
        layout.template_ID(window, "scene", new="scene.new", unlink="scene.delete")

        row = layout.row(align=True)
        row.template_search(
            window, "view_layer",
            scene, "view_layers",
            new="scene.view_layer_add",
            unlink="scene.view_layer_remove")
